/**
 * 企业信息
 * 汇总
 * 
 *
 * */
 

import { ApplyForUpdateConfig, GardenNoticeUpdateConfig, PolicyUpdateConfig, RegisterUpdateConfig, SettleInForUpdateConfig } from "../config/eccParam/enterprise";
import { OPERATIONALDATATYPE, TABLEID, TABLENAME } from "../config/enum/dbEnum";
import * as enumConfig from "../config/enum/enum";
import { operationalData, selectData, selectManyTableData } from "../data/operationalData";
import { BizError } from "../util/bizError";
import { eccFormParam } from "../util/verificationParam";
import { ERRORENUM } from "../config/enum/errorEnum";
import { getMySqlMs, getToken, md5PwdStr, randomCode, randomId } from "../tools/system";
import moment = require("moment");
import { changeAdd, extractData } from "../util/piecemeal";
import { EnterpriseApplyForConfig } from "../config/splitResult/enterprise";
import { changeEnumValue } from "../util/verificationEnum";
import { count } from "console";

export async function allEntepriseNameList() {
    let listList = await selectData(OPERATIONALDATATYPE.查询多个, TABLENAME.企业基础信息表, {state:1}, ["enterpriseName", "eId"]);

    let dataList = [];
    listList.forEach(info => {
        dataList.push({
            key:info.enterpriseName,
            value:info.eId
        })
    });

    return {dataList}
}




//企业申请上传资料
export async function enterpriseApplyFor(eId:string) {
    let filesList = ["eId", "uscc", "enterpriseName", "logonAddress", "logonTime"];
    let enterpriseUserInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业基础信息表, {eId}, filesList);
    if (!enterpriseUserInfo || !enterpriseUserInfo.eId) {
        throw new BizError(ERRORENUM.请先申请入孵);
    }
    let leaseFilesList = ["leaseId", "startTime", "endTime", "area", "leaseContract", "entryPlan", "businessLicense", "agreement"];
    let leaseInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.租赁信息, {eId}, leaseFilesList);
    enterpriseUserInfo.logonAddress = JSON.parse(enterpriseUserInfo.logonAddress);
    let dataInfo:any = extractData(EnterpriseApplyForConfig, enterpriseUserInfo);

    dataInfo.logonTime = moment(enterpriseUserInfo.logonTime).format("YYYY-MM-DD");
    dataInfo.leaseTime = `${moment(leaseInfo.startTime).format("YYYY-MM-DD")}至${moment(leaseInfo.endTime).format("YYYY-MM-DD")}`;
    dataInfo.area = leaseInfo.area;

    dataInfo.leaseContract = leaseInfo.leaseContract;
    dataInfo.entryPlan = leaseInfo.entryPlan;
    dataInfo.businessLicense = leaseInfo.businessLicense;
    dataInfo.agreement = leaseInfo.agreement;

    dataInfo.leaseContractModelUrl = "/yuyi/files/孵化协议模板.docx";
    dataInfo.entryPlanModelUrl = "/yuyi/files/孵化企业入驻计划.xlsx";
    dataInfo.agreementModelUrl = "/yuyi/files/三方协议.docx";


    return {dataInfo};
}

export async function updateEnterpriseApplyFor(eId:string, param) {
    const FuncName = "企业修改入驻信息";
    eccFormParam(FuncName, ApplyForUpdateConfig, param );
    let filesList = ["eId", "enterpriseName", "uscc", "logonTime", "state"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业基础信息表, {eId}, filesList);
    if (!resInfo || !resInfo.eId) {
        throw new BizError(ERRORENUM.数据不存在);
    }
    if (resInfo.state == 1) {
        throw new BizError(ERRORENUM.已审核请前往小程序登录)
    } 

    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.租赁信息, param, {eId});

    return {isSuccess:true};
}


export async function enterpriseExamineList(year:number, entepriseName:string, page:number) {
    let filesList = [ "mId", "annual",  "BI", "TXP", "RD", "state"];
    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业基础信息表] = {column:["enterpriseName"], where:{} };
    if (entepriseName) {
        manyTableInfo[TABLENAME.企业基础信息表].where["enterpriseName"] = {"%like%":entepriseName}
    }
    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.企业经营信息, {annual:getMySqlMs(year)}, filesList, manyTableInfo, page);
    let dataCount = await selectData(OPERATIONALDATATYPE.查询数据量, TABLENAME.企业经营信息, {annual:getMySqlMs(year)}, null);

    let dataList = [];
    resInfo.forEach(info => {
        let dataInfo = {
            enterpriseName:info.enterprise.enterpriseName,
            mId:info.mId,
            annual:moment(info.annual).format("YYYY"),
            BI:info.BI,
            TXP:info.TXP,
            RD:info.RD,
            state:info.state
        };
        dataList.push(dataInfo);
    })
    

    return {dataList, dataCount};
}



export async function enterpriseExamineInfo(mId:string) {
    let filesList = [ "mId", "annual",  "BI", "TXP", "RD"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业经营信息, {mId}, filesList);
    if (!resInfo || !resInfo.mId) {
        throw new BizError(ERRORENUM.数据不存在);
    }

    let dataInfo = {
        mId:resInfo.mId,
        BI:resInfo.BI,
        TXP:resInfo.TXP,
        RD:resInfo.RD
    }

    return {dataInfo};
}

export async function enterpriseExamineUpdate( mId, param) {
    let filesList = [ "eId", "annual",  "BI", "TXP", "RD"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业经营信息, {mId}, filesList);
    if (!resInfo || !resInfo.eId) {
        throw new BizError(ERRORENUM.数据不存在);
    }

    let dataInfo = {
        BI:param.BI,
        TXP:param.TXP,
        RD:param.RD
    }

    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.企业经营信息, dataInfo, {mId});

    return {dataInfo};
}

export async function enterpriseExaminePass(mId) {
    let filesList = [ "eId", "annual",  "BI", "TXP", "RD"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业经营信息, {mId}, filesList);
    if (!resInfo || !resInfo.eId) {
        throw new BizError(ERRORENUM.数据不存在);
    }

    let dataInfo = {
        state:enumConfig.STATE.是
    }

    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.企业经营信息, dataInfo, {mId});

    return {dataInfo};
}




export async function enterpriseManageList(entepriseName:string, year:number, page:number, state:number) {
  
    let selectParam:any = {};
    if (year) {
        selectParam.annual = getMySqlMs(year);
    }
    if (state) {
        if (state == 1) selectParam.state = 1;
        else selectParam.state = 0;
    }
    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业基础信息表] = {column: ["enterpriseName", "uscc"], where:{} };
    if (entepriseName) {
        manyTableInfo[TABLENAME.企业经营信息].where["enterpriseName"] = {"%like%":entepriseName}
    }
    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.企业经营信息, selectParam, ["mId", "BI", "TXP", "RD", "annual"], manyTableInfo, page);
    let dataCountList = await selectManyTableData(OPERATIONALDATATYPE.多表联查, TABLENAME.企业经营信息, selectParam, ["eId"], manyTableInfo);
    
    let dataCount = dataCountList.length;
    let dataList = [];
    resInfo.forEach(info => {
        let {BI, mId, TXP,RD,state,annual, enterprise} = info;
        let dataInfo = {
            enterpriseName:enterprise.enterpriseName, //企业名称
            uscc:enterprise.uscc, //统一信用代码
            BI, //营收（万元）
            TXP:TXP, //纳税（万元）
            RD:RD,//研发投入（万元）
            annual:moment(annual).format("YYYY"),//年度
            state:state ? "已审核" : "未审核",
            mId:mId
        };
        dataList.push(dataInfo);
    });

    return {dataList, dataCount};
}



export async function outPutEnterpriseManageList(entepriseName:string, year:number, state:number, type:number, files) {
  
    let selectParam:any = {};
    if (type == 1) {
        if (year) {
            selectParam.annual = getMySqlMs(year);
        }
        if (state) {
            if (state == 1) selectParam.state = 1;
            else selectParam.state = 0;
        }
    }
   
    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业基础信息表] = {column: ["enterpriseName", "uscc"], where:{} };
    if (entepriseName && type == 1) {
        manyTableInfo[TABLENAME.企业经营信息].where["enterpriseName"] = {"%like%":entepriseName}
    }
    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表联查, TABLENAME.企业经营信息, selectParam, ["mId", "BI", "TXP", "RD", "annual"], manyTableInfo);
   


    let dataList = [];
    let titleList = []
    let valueList = [];
    files.forEach(item => {
        titleList.push(item.key);
        valueList.push(item.value);
    });
    dataList.push(titleList);

    resInfo.forEach(info => {
        let {BI, mId, TXP,RD,state,annual, enterprise} = info;
        let subList = [];
        let stateStr = state ? "已审核" : "未审核";
        valueList.forEach(subInfo => {
            if (subInfo == "enterpriseName") subList.push(enterprise.enterpriseName);
            if (subInfo == "uscc") subList.push(enterprise.uscc);
            if (subInfo == "BI") subList.push(BI);
            if (subInfo == "TXP") subList.push(TXP);
            if (subInfo == "RD") subList.push(RD);
            if (subInfo == "annual") subList.push(moment(annual).format("YYYY"));
            if (subInfo == "state") subList.push(stateStr);
        });
        dataList.push(subList);
    });

    return {dataList};
}



export async function enterpriseManagePass(mId:string) {
    let info = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业经营信息, {mId}, ["mId"]);

    if (!info || !info.mId) throw new BizError(ERRORENUM.当前数据不存在);

    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.企业经营信息, {state:1}, {mId} );

    return {isSuccess:true};
}



//====融资
export async function enterpriseFinancingList(entepriseName:string,page:number) {
    let selectParam:any = {state:enumConfig.STATE.是};
    if (entepriseName) {
        selectParam.entepriseName = {"%like%":entepriseName}
    }

    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业融资] = {column:["financingAmount", "financingRounds", "investmentDate", "investmentInstitutionsName" ], where:{} };
    let filesList = ["enterpriseName", "uscc"];
    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.企业基础信息表, selectParam, filesList, manyTableInfo, page);
    let dataCountList = await selectManyTableData(OPERATIONALDATATYPE.多表联查, TABLENAME.企业基础信息表, selectParam, ["eId"], manyTableInfo);
    let dataCount = dataCountList.length;

    let dataList = [];
    resInfo.forEach(info => {
        let {enterpriseName, uscc, enterprise_financings} = info;
        let dataInfo = {
            enterpriseName, //企业名称
            uscc, //统一信用代码
            financingAmount:enterprise_financings[0].financingAmount, //融资金额（万元）
            financingRounds:changeEnumValue(enumConfig.FINANCINGROUNDS, enterprise_financings[0].financingRounds), //融资轮次
            investmentDate:moment(enterprise_financings[0].investmentDate).format("YYYY-MM-DD"),//获得投资时间
            investmentInstitutionsName:enterprise_financings[0].investmentInstitutionsName,//投资机构名称
        };
        dataList.push(dataInfo);
    });

    return {dataList, dataCount};
}

export async function outPutEnterpriseFinancingList(entepriseName:string, type:number, files) {
    let selectParam:any = {state:enumConfig.STATE.是};

    if (type == 1) {
        if (entepriseName) {
            selectParam.entepriseName = {"%like%":entepriseName}
        }
    }

    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业融资] = {column:["financingAmount", "financingRounds", "investmentDate", "investmentInstitutionsName" ], where:{} };
    let filesList = ["enterpriseName", "uscc"];
    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表联查, TABLENAME.企业基础信息表, selectParam, filesList, manyTableInfo);


    let dataList = [];
    let titleList = [];
    let valueList = [];
    files.forEach(item => {
        titleList.push(item.key);
        valueList.push(item.value);
    });
    dataList.push(titleList);
    resInfo.forEach(info => {
        let {enterpriseName, uscc, enterprise_financings} = info;
        
        let subList = [];

        valueList.forEach(subInfo => {
            if (subInfo == "enterpriseName") subList.push(enterpriseName);
            if (subInfo == "uscc") subList.push(uscc);
            if (subInfo == "financingAmount") subList.push(enterprise_financings[0].financingAmount);
            if (subInfo == "financingRounds") subList.push(changeEnumValue(enumConfig.FINANCINGROUNDS, enterprise_financings[0].financingRounds));
            if (subInfo == "investmentDate") subList.push(moment(enterprise_financings[0].investmentDate).format("YYYY-MM-DD"));
            if (subInfo == "investmentInstitutionsName") subList.push(enterprise_financings[0].investmentInstitutionsName);
        });

        dataList.push(subList);
    });

    return {dataList};
}




export async function enterpriseTalentList(name:string, page:number) {
    let selectParam:any = {};
    if (name) {
        selectParam.name = {"%like%":name};
    }

    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业基础信息表] = {column:["enterpriseName" ], where:{} };
    let filesList = ["name", "sex", "birth", "degree", "graduationSchool"];
    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.创业团队, selectParam, filesList, manyTableInfo, page);
    let dataCount = await selectData(OPERATIONALDATATYPE.查询数据量, TABLENAME.创业团队, selectParam, null);

    let dataList = [];
    resInfo.forEach(info => {
        let {name, sex, birth, degree, graduationSchool, enterprise} = info;
        let dataInfo = {
            name, //姓名
            sex:changeEnumValue(enumConfig.SEX, sex), //性别
            birth:moment(birth).format("YYYY-MM-DD"), //出生年月
            degree:changeEnumValue(enumConfig.DEGREE, degree), //最高学历
            graduationSchool,//毕业学校
            enterpriseName:enterprise.enterpriseName,//企业名称
        };
        dataList.push(dataInfo);
    });

    return {dataList, dataCount};
}


export async function outPutEnterpriseTalentList(name:string, type:number, files) {
    let selectParam:any = {};
    if (type == 1) {
        if (name) {
            selectParam.name = {"%like%":name};
        }
    }
    
    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业基础信息表] = {column:["enterpriseName" ], where:{} };
    let filesList = ["name", "sex", "birth", "degree", "graduationSchool"];
    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表联查, TABLENAME.创业团队, selectParam, filesList, manyTableInfo);

    let dataList = [];
    let titleList = [];
    let valueList = [];
    files.forEach(item => {
        titleList.push(item.key);
        valueList.push(item.value);
    });
    dataList.push(titleList);
    resInfo.forEach(info => {
        let {name, sex, birth, degree, graduationSchool, enterprise} = info;
        let subList = [];
      
        valueList.forEach(subInfo => {
            if (subInfo == "name") subList.push(name);
            if (subInfo == "sex") subList.push(changeEnumValue(enumConfig.SEX, sex));
            if (subInfo == "birth") subList.push(moment(birth).format("YYYY-MM-DD"));
            if (subInfo == "degree") subList.push(changeEnumValue(enumConfig.DEGREE, degree));
            if (subInfo == "graduationSchool") subList.push(graduationSchool);
            if (subInfo == "enterpriseName") subList.push(enterprise.enterpriseName);
        });
        dataList.push(subList);
    });

    return {dataList};
}



export async function iprList(enterpriseName, page) {
    let selectParam:any = {};
    if (enterpriseName) {
        selectParam.enterpriseName = {"%like%":enterpriseName};
    }
    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业专利表] = {column:["year", "alienPatent", "classIPatent", "secondClassPatent", "thirdPentent"], where:{} };
    manyTableInfo[TABLENAME.知识产权] = {column:["number"], where:{}};

    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.企业基础信息表, selectParam, ["enterpriseName", "uscc"], manyTableInfo, page);
    let allDataList = await selectManyTableData(OPERATIONALDATATYPE.多表联查, TABLENAME.企业基础信息表, selectParam, ["enterpriseName", "uscc"], manyTableInfo);
    
    let dataList = [];
    resInfo.forEach(info => {
        let {uscc, enterpriseName, enterprise_iprs, enterprise_patents} = info;
        let addItem = {
            uscc, 
            enterpriseName, 
            alienPatent:undefined, 
            classIPatent:undefined, 
            secondClassPatent:undefined, 
            thirdPentent:undefined,
            count:undefined
        };
        for (let i = 0; i < enterprise_patents.length; i++) {
            let item = enterprise_patents[i];
            if (item.alienPatent) {
                if (addItem.alienPatent == undefined) addItem.alienPatent = 0;
                addItem.alienPatent += item.alienPatent;
            } 
            if (item.classIPatent) {
                if (addItem.classIPatent == undefined) addItem.classIPatent = 0;
                addItem.classIPatent += item.classIPatent;
            } 
            if (item.secondClassPatent) {
                if (addItem.secondClassPatent == undefined) addItem.secondClassPatent = 0;
                addItem.secondClassPatent += item.secondClassPatent;
            } 
            if (item.thirdPentent) {
                if (addItem.thirdPentent == undefined) addItem.thirdPentent = 0;
                addItem.thirdPentent += item.thirdPentent;
            }
        }
        for (let i = 0; i < enterprise_iprs.length; i++) {
            let item = enterprise_iprs[i];
            if (item.number) {
                if (addItem.count == undefined) addItem.count = 0;
                addItem.count += item.number;
            } 
        }

        for (let key in addItem) {
            if (addItem[key] == undefined) addItem[key] = "-";
        }
        dataList.push(addItem);
    });

    

    return {dataList, dataCount:allDataList.length}; 
}


export async function qiyeRenZheng(enterpriseName, page) {
    let selectParam:any = {};
    if (enterpriseName) {
        selectParam.enterpriseName = {"%like%":enterpriseName};
    }
    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业资质] = {column:["kxTime", "zjtxTime", "xjrTime", "xjrPyTime", "goPublicTime", "gaoXinJiShuTime", "goPublicSector"], where:{} };

    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.企业基础信息表, selectParam, ["enterpriseName", "uscc"], manyTableInfo, page);
    let allDataList = await selectManyTableData(OPERATIONALDATATYPE.多表联查, TABLENAME.企业基础信息表, selectParam, ["enterpriseName", "uscc"], manyTableInfo);
    
    let dataList = [];
    resInfo.forEach(info => {
        let {uscc, enterpriseName, enterprise_qualifications} = info;
        let addItem = {
            uscc, 
            enterpriseName, 
            kxTime:"-",
            zjtxTime:"-",
            xjrTime:"-",
            xjrPyTime:"-",
            goPublicTime:"-",
            gaoXinJiShuTime:"-",
            goPublicSector:"-",
        };
        for (let i = 0; i < enterprise_qualifications.length; i++) {
            let item = enterprise_qualifications[i];
            if (item.kxTime) addItem.kxTime = moment(item.kxTime).format("YYYY");
            if (item.zjtxTime) addItem.zjtxTime = moment(item.zjtxTime).format("YYYY");
            if (item.xjrTime) addItem.xjrTime = moment(item.xjrTime).format("YYYY");
            if (item.xjrPyTime) addItem.xjrPyTime = moment(item.xjrPyTime).format("YYYY");
            if (item.goPublicTime) addItem.goPublicTime = moment(item.goPublicTime).format("YYYY");
            if (item.gaoXinJiShuTime) addItem.gaoXinJiShuTime = moment(item.gaoXinJiShuTime).format("YYYY");
            if (item.goPublicSector && item.goPublicSector != "[]") {
                addItem.goPublicSector = changeEnumValue(enumConfig.FINANCINGROUNDS, JSON.parse(item.goPublicSector));
            }
        }

        dataList.push(addItem);
    });

    return {dataList, dataCount:allDataList.length}; 
}




export async function enterpriseHonor(enterpriseName, page) {
    let selectParam:any = {};
    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业基础信息表] = {column:["enterpriseName", "uscc"], where:{} };

    if (enterpriseName) {
        manyTableInfo[TABLENAME.企业基础信息表].where["enterpriseName"] = {"%like%":enterpriseName};
    }

    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.企业荣誉, selectParam, ["awardName", "awardingUnit", "awardTime", "awardLevel"], manyTableInfo, page);
    let allDataList = await selectManyTableData(OPERATIONALDATATYPE.多表联查, TABLENAME.企业荣誉, selectParam, ["awardName", "awardingUnit", "awardTime", "awardLevel"], manyTableInfo);
    
    let dataList = [];
    resInfo.forEach(info => {
        let {enterprise, awardName, awardingUnit, awardTime, awardLevel} = info;
        let addItem = {
            uscc:enterprise.uscc, 
            enterpriseName:enterprise.enterpriseName,
            awardName, awardingUnit, awardTime, awardLevel:changeEnumValue(enumConfig.AWARDLEVEL,awardLevel)
        };
        
        dataList.push(addItem);
    });

    return {dataList, dataCount:allDataList.length}; 
}
